# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health_checks_common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ahealth_checks_common.proto\x12!armonik.api.grpc.v1.health_checks\"\x14\n\x12\x43heckHealthRequest\"\xe3\x01\n\x13\x43heckHealthResponse\x12V\n\x08services\x18\x01 \x03(\x0b\x32\x44.armonik.api.grpc.v1.health_checks.CheckHealthResponse.ServiceHealth\x1at\n\rServiceHealth\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x44\n\x07healthy\x18\x03 \x01(\x0e\x32\x33.armonik.api.grpc.v1.health_checks.HealthStatusEnum*\x99\x01\n\x10HealthStatusEnum\x12\"\n\x1eHEALTH_STATUS_ENUM_UNSPECIFIED\x10\x00\x12\x1e\n\x1aHEALTH_STATUS_ENUM_HEALTHY\x10\x01\x12\x1f\n\x1bHEALTH_STATUS_ENUM_DEGRADED\x10\x02\x12 \n\x1cHEALTH_STATUS_ENUM_UNHEALTHY\x10\x03\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.HealthChecksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'health_checks_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.HealthChecks'
  _globals['_HEALTHSTATUSENUM']._serialized_start=318
  _globals['_HEALTHSTATUSENUM']._serialized_end=471
  _globals['_CHECKHEALTHREQUEST']._serialized_start=65
  _globals['_CHECKHEALTHREQUEST']._serialized_end=85
  _globals['_CHECKHEALTHRESPONSE']._serialized_start=88
  _globals['_CHECKHEALTHRESPONSE']._serialized_end=315
  _globals['_CHECKHEALTHRESPONSE_SERVICEHEALTH']._serialized_start=199
  _globals['_CHECKHEALTHRESPONSE_SERVICEHEALTH']._serialized_end=315
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import health_checks_common_pb2 as health__checks__common__pb2


class HealthChecksServiceStub(object):
    """*
    The HealthChecksService provides methods to verify the health of the cluster.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CheckHealth = channel.unary_unary(
                '/armonik.api.grpc.v1.health_checks.HealthChecksService/CheckHealth',
                request_serializer=health__checks__common__pb2.CheckHealthRequest.SerializeToString,
                response_deserializer=health__checks__common__pb2.CheckHealthResponse.FromString,
                )


class HealthChecksServiceServicer(object):
    """*
    The HealthChecksService provides methods to verify the health of the cluster.
    """

    def CheckHealth(self, request, context):
        """*
        Checks the health of the cluster. This can be used to verify that the cluster is up and running.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HealthChecksServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CheckHealth': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckHealth,
                    request_deserializer=health__checks__common__pb2.CheckHealthRequest.FromString,
                    response_serializer=health__checks__common__pb2.CheckHealthResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.health_checks.HealthChecksService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HealthChecksService(object):
    """*
    The HealthChecksService provides methods to verify the health of the cluster.
    """

    @staticmethod
    def CheckHealth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.health_checks.HealthChecksService/CheckHealth',
            health__checks__common__pb2.CheckHealthRequest.SerializeToString,
            health__checks__common__pb2.CheckHealthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
